==> cz-conventional-changelog-emoji-0.0.5.tgz: package/readme.md <==
# [cz-conventional-changelog-emoji](https://www.npmjs.com/package/cz-conventional-changelog-emoji)

[![Javascript](https://badges.frapsoft.com/javascript/code/javascript.svg?v=100)](https://github.com/ellerbrock/javascript-badges/) [![Open Source Love](https://badges.frapsoft.com/os/v1/open-source.svg?v=102)](https://github.com/ellerbrock/open-source-badges/) [![Gitter Chat](https://badges.gitter.im/frapsoft/frapsoft.svg)](https://gitter.im/frapsoft/frapsoft/)

## [Angular Git Commit Guidelines](https://github.com/angular/angular.js/blob/master/CONTRIBUTING.md#type) with Emojis 

*This is a fork from [cz-conventional-changelog](https://github.com/commitizen/cz-conventional-changelog).*


![commitizen emoji](https://github.frapsoft.com/top/commitizen-emoji.jpg?v=101)

### Hell yeah, how?

```bash
npm install -g commitizen
commitizen init cz-conventional-changelog-emoji --save-dev --save-exact
```

### What's about Changelog?

`npm install --save-dev conventional-changelog-angular-emoji`

<https://www.npmjs.com/package/conventional-changelog-angular-emoji>

and add this to your package.json

```
  "commitizen": {
    "path": "cz-conventional-changelog-emoji"
  },
```

### Dude just let me use it

No time for setting up all that stuff?  
No worries! All that and lot more awesome stuff ready to use with [node-developer-boilerplate](https://github.com/ellerbrock/node-developer-boilerplate).

### Preview:

feat(xxx): :sparkles: Features your commit message
	
fix(xxx): :bug: Bug Fixes
	
docs(xxx): :book: Documentation

style: :gem: Styles

refactor: :package: Code Refactoring

perf(xxx): :rocket: Performance Improvements

test(xxx): :rotating_light: Tests

build(xxx): :construction_worker: Build

ci(xxx): :computer: Continuous Integration
    
chore(xxx): :ticket: Chores

revert(xxx): :back: Reverts

### Video Course on [egghead.io](https://egghead.io)

- [Writing conventional commits with commitizen](https://egghead.io/lessons/javascript-how-to-write-a-javascript-library-writing-conventional-commits-with-commitizen)
- [Committing a new feature with commitizen](https://egghead.io/lessons/javascript-how-to-write-a-javascript-library-committing-a-new-feature-with-commitizen)

### Contact / Social Media

_Get the latest News about Web Development, Open Source, Tooling, Server & Security_

[![Twitter](https://github.frapsoft.com/social/twitter.png)](https://twitter.com/frapsoft/)[![Facebook](https://github.frapsoft.com/social/facebook.png)](https://www.facebook.com/frapsoft/)[![Google+](https://github.frapsoft.com/social/google-plus.png)](https://plus.google.com/116540931335841862774)[![Gitter](https://github.frapsoft.com/social/gitter.png)](https://gitter.im/frapsoft/frapsoft/)[![Github](https://github.frapsoft.com/social/github.png)](https://github.com/ellerbrock/)

### License

Copyright (c) 2016 [Maik Ellerbrock](https://github.com/ellerbrock/)

[![MIT Licence](https://badges.frapsoft.com/os/mit/mit-125x28.png?v=102)](https://opensource.org/licenses/mit-license.php)

==> cz-conventional-changelog-emoji-0.1.0.tgz: package/readme.md <==
# [cz-conventional-changelog-emoji](https://www.npmjs.com/package/cz-conventional-changelog-emoji)

[![Javascript](https://badges.frapsoft.com/javascript/code/javascript.svg?v=100)](https://github.com/ellerbrock/javascript-badges/) [![Open Source Love](https://badges.frapsoft.com/os/v1/open-source.svg?v=102)](https://github.com/ellerbrock/open-source-badges/) [![Gitter Chat](https://badges.gitter.im/frapsoft/frapsoft.svg)](https://gitter.im/frapsoft/frapsoft/)

## [Angular Git Commit Guidelines](https://github.com/angular/angular.js/blob/master/CONTRIBUTING.md#type) with Emojis 

*This is a fork from [cz-conventional-changelog](https://github.com/commitizen/cz-conventional-changelog).*


![commitizen emoji](https://github.frapsoft.com/top/commitizen-emoji.jpg?v=101)

### Hell yeah, how?

```bash
npm install -g commitizen cz-conventional-changelog-emoji
commitizen init cz-conventional-changelog-emoji --save-dev --save-exact
```

the command add this to your package.json:

```
  "commitizen": {
    "path": "cz-conventional-changelog-emoji"
  },
```

### What's about Changelog?

`npm install --save-dev conventional-changelog-angular-emoji`

<https://www.npmjs.com/package/conventional-changelog-angular-emoji>


### Dude just let me use it

No time for setting up all that stuff?  
No worries! All that and lot more awesome stuff ready to use with [node-developer-boilerplate](https://github.com/ellerbrock/node-developer-boilerplate).

### Preview:

feat(xxx): :sparkles: Features your commit message
	
fix(xxx): :bug: Bug Fixes
	
docs(xxx): :book: Documentation

style: :gem: Styles

refactor: :package: Code Refactoring

perf(xxx): :rocket: Performance Improvements

test(xxx): :rotating_light: Tests

build(xxx): :construction_worker: Build

ci(xxx): :computer: Continuous Integration
    
chore(xxx): :ticket: Chores

revert(xxx): :back: Reverts

### Video Course on [egghead.io](https://egghead.io)

- [Writing conventional commits with commitizen](https://egghead.io/lessons/javascript-how-to-write-a-javascript-library-writing-conventional-commits-with-commitizen)
- [Committing a new feature with commitizen](https://egghead.io/lessons/javascript-how-to-write-a-javascript-library-committing-a-new-feature-with-commitizen)

### Contact / Social Media

_Get the latest News about Web Development, Open Source, Tooling, Server & Security_

[![Twitter](https://github.frapsoft.com/social/twitter.png)](https://twitter.com/frapsoft/)[![Facebook](https://github.frapsoft.com/social/facebook.png)](https://www.facebook.com/frapsoft/)[![Google+](https://github.frapsoft.com/social/google-plus.png)](https://plus.google.com/116540931335841862774)[![Gitter](https://github.frapsoft.com/social/gitter.png)](https://gitter.im/frapsoft/frapsoft/)[![Github](https://github.frapsoft.com/social/github.png)](https://github.com/ellerbrock/)

### License

Copyright (c) 2016 [Maik Ellerbrock](https://github.com/ellerbrock/)

[![MIT Licence](https://badges.frapsoft.com/os/mit/mit-125x28.png?v=102)](https://opensource.org/licenses/mit-license.php)
